==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/nl-NL/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Speciale velden',
    'manage'                    => 'Beheren',
    'field'		                => 'Veld',
    'about_fieldsets_title'		=> 'Over veldverzamelingen',
    'about_fieldsets_text'		=> 'Veldverzamelingen stellen je in staat groepen van aangepaste velden te maken die vaak worden hergebruikt voor specifieke soorten asset modellen.',
    'custom_format'             => 'Aangepaste Regex formaat...',
    'encrypt_field'      	        => 'Versleutel de waarde van dit veld in de database',
    'encrypt_field_help'      => 'Waarschuwing: Versleutelen van dit veld maakt het onmogelijk om hierop te zoeken.',
    'encrypted'      	        => 'Versleuteld',
    'fieldset'      	        => 'Veldverzameling',
    'qty_fields'      	      => 'Aantal Velden',
    'fieldsets'      	        => 'Veldverzamelingen',
    'fieldset_name'           => 'Naam veldverzameling',
    'field_name'              => 'Veldnaam',
    'field_values'            => 'Veldwaarden',
    'field_values_help'       => 'Voeg selecteerbare optie toe, één per regel. Alle blanco regels behalve de eerste regel zullen worden genegeerd.',
    'field_element'           => 'Formulierelement',
    'field_element_short'     => 'Element',
    'field_format'            => 'Indeling',
    'field_custom_format'     => 'Aangepaste regex-indeling',
    'field_custom_format_help'     => 'Dit veld laat u toe om een regex expressie te gebruiken om te valideren. Het moet beginnen met "regex:" - bijvoorbeeld, om een waarde in een speciaal veld te valideren dat een geldig IMEI nummer (15 cijfers) bevat, gebruik je <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Vereist',
    'req'   		              => 'Verpl.',
    'used_by_models'   		    => 'Gebruikt door modellen',
    'order'   		            => 'Bestelling',
    'create_fieldset'         => 'Nieuwe veldset',
    'update_fieldset'         => 'Veldverzameling bijwerken',
    'fieldset_does_not_exist'   => 'Veldverzameling :id bestaat niet',
    'fieldset_updated'         => 'Veldverzameling bijgewerkt',
    'create_fieldset_title' => 'Maak een nieuwe veldset aan',
    'create_field'            => 'Nieuw aangepast veld',
    'create_field_title' => 'Maak een nieuw aangepast veld',
    'value_encrypted'      	        => 'De waarde van dit veld is versleuteld in de database. Alleen beheerders zullen de onversleutelde waarde kunnen weergeven.',
    'show_in_email'     => 'De waarde van dit veld opnemen in de checkout e-mails die naar de gebruiker zijn verzonden? Versleutelde velden kunnen niet worden opgenomen in e-mails',
    'show_in_email_short'     => 'Opnemen in e-mails.',
    'help_text' => 'Help tekst',
    'help_text_description' => 'Dit is een optionele tekst die onder de formulierelementen verschijnt terwijl een asset wordt bewerkt om context op te geven in het veld.',
    'about_custom_fields_title' => 'Over Aangepaste Velden',
    'about_custom_fields_text' => 'Met Aangepaste velden kun je willekeurige attributen toevoegen aan assets.',
    'add_field_to_fieldset' => 'Veld toevoegen aan veldset',
    'make_optional' => 'Vereist - klik om optioneel te maken',
    'make_required' => 'Optioneel - klik om vereist te maken',
    'reorder' => 'Herordenen',
    'db_field' => 'DB-veld',
    'db_convert_warning' => 'WAARSCHUWING. Dit veld staat in de tabel met aangepaste velden als <code> :db_column </code> maar moet :expected </code> zijn.',
    'is_unique' => 'Deze waarde moet uniek zijn voor alle assets',
    'unique' => 'Uniek',
    'display_in_user_view' => 'Laat de uitgecheckte gebruiker deze waarden zien in de weergave van toegewezen bezittingen pagina',
    'display_in_user_view_table' => 'Zichtbaar voor gebruiker',
    'auto_add_to_fieldsets' => 'Automatisch toevoegen aan elke nieuwe veldverzameling',
    'add_to_preexisting_fieldsets' => 'Aan elk bestaande veldverzameling toevoegen',
    'show_in_listview' => 'Standaard weergeven in lijstweergaven. Geautoriseerde gebruikers kunnen nog steeds weergeven/verbergen via de kolom instellingen',
    'show_in_listview_short' => 'Toon in lijsten',
    'show_in_requestable_list_short' => 'Toon in de aanvraagbare assets lijst',
    'show_in_requestable_list' => 'Toon de waarde in de aanvraagbare assets lijst. Gecodeerde velden worden niet getoond',
    'encrypted_options' => 'Dit veld is encrypted, dus sommige weergaveopties zullen niet beschikbaar zijn.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/nl-NL/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Speciale velden',
    'manage'                    => 'Beheren',
    'field'		                => 'Veld',
    'about_fieldsets_title'		=> 'Over veldverzamelingen',
    'about_fieldsets_text'		=> 'Veldverzamelingen stellen je in staat groepen van aangepaste velden te maken die vaak worden hergebruikt voor specifieke soorten asset modellen.',
    'custom_format'             => 'Aangepaste Regex formaat...',
    'encrypt_field'      	        => 'Versleutel de waarde van dit veld in de database',
    'encrypt_field_help'      => 'Waarschuwing: Versleutelen van dit veld maakt het onmogelijk om hierop te zoeken.',
    'encrypted'      	        => 'Versleuteld',
    'fieldset'      	        => 'Veldverzameling',
    'qty_fields'      	      => 'Aantal Velden',
    'fieldsets'      	        => 'Veldverzamelingen',
    'fieldset_name'           => 'Naam veldverzameling',
    'field_name'              => 'Veldnaam',
    'field_values'            => 'Veldwaarden',
    'field_values_help'       => 'Voeg selecteerbare optie toe, één per regel. Alle blanco regels behalve de eerste regel zullen worden genegeerd.',
    'field_element'           => 'Formulierelement',
    'field_element_short'     => 'Element',
    'field_format'            => 'Indeling',
    'field_custom_format'     => 'Aangepaste regex-indeling',
    'field_custom_format_help'     => 'Dit veld laat u toe om een regex expressie te gebruiken om te valideren. Het moet beginnen met "regex:" - bijvoorbeeld, om een waarde in een speciaal veld te valideren dat een geldig IMEI nummer (15 cijfers) bevat, gebruik je <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Vereist',
    'req'   		              => 'Verpl.',
    'used_by_models'   		    => 'Gebruikt door modellen',
    'order'   		            => 'Bestelling',
    'create_fieldset'         => 'Nieuwe veldset',
    'update_fieldset'         => 'Veldverzameling bijwerken',
    'fieldset_does_not_exist'   => 'Veldverzameling :id bestaat niet',
    'fieldset_updated'         => 'Veldverzameling bijgewerkt',
    'create_fieldset_title' => 'Maak een nieuwe veldset aan',
    'create_field'            => 'Nieuw aangepast veld',
    'create_field_title' => 'Maak een nieuw aangepast veld',
    'value_encrypted'      	        => 'De waarde van dit veld is versleuteld in de database. Alleen beheerders zullen de onversleutelde waarde kunnen weergeven.',
    'show_in_email'     => 'De waarde van dit veld opnemen in de checkout e-mails die naar de gebruiker zijn verzonden? Versleutelde velden kunnen niet worden opgenomen in e-mails',
    'show_in_email_short' => 'Opnemen in e-mails',
    'help_text' => 'Help tekst',
    'help_text_description' => 'Dit is een optionele tekst die onder de formulierelementen verschijnt terwijl een asset wordt bewerkt om context op te geven in het veld.',
    'about_custom_fields_title' => 'Over Aangepaste Velden',
    'about_custom_fields_text' => 'Met Aangepaste velden kun je willekeurige attributen toevoegen aan assets.',
    'add_field_to_fieldset' => 'Veld toevoegen aan veldset',
    'make_optional' => 'Vereist - klik om optioneel te maken',
    'make_required' => 'Optioneel - klik om vereist te maken',
    'reorder' => 'Herordenen',
    'db_field' => 'DB-veld',
    'db_convert_warning' => 'WAARSCHUWING. Dit veld staat in de tabel met aangepaste velden als <code> :db_column </code> maar moet :expected </code> zijn.',
    'is_unique' => 'Deze waarde moet uniek zijn voor alle assets',
    'unique' => 'Uniek',
    'display_in_user_view' => 'Laat de uitgecheckte gebruiker deze waarden zien in de weergave van toegewezen bezittingen pagina',
    'display_in_user_view_table' => 'Zichtbaar voor gebruiker',
    'auto_add_to_fieldsets' => 'Automatisch toevoegen aan elke nieuwe veldverzameling',
    'add_to_preexisting_fieldsets' => 'Aan elk bestaande veldverzameling toevoegen',
    'show_in_listview' => 'Standaard weergeven in lijstweergaven. Geautoriseerde gebruikers kunnen nog steeds weergeven/verbergen via de kolom instellingen',
    'show_in_listview_short' => 'Toon in lijsten',
    'show_in_requestable_list_short' => 'Toon in de aanvraagbare assets lijst',
    'show_in_requestable_list' => 'Toon de waarde in de aanvraagbare assets lijst. Gecodeerde velden worden niet getoond',
    'encrypted_options' => 'Dit veld is encrypted, dus sommige weergaveopties zullen niet beschikbaar zijn.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
